@@ -112,7 +112,7 @@ file_selector_response_cb (GtkWidget    *widget,
 					   GTK_DIALOG_MODAL,
 					   NULL,
 					   _("Could not add the files to the archive"),
-					   _("You don't have the right permissions to read files from folder \"%s\""),
+					   _("You don’t have the right permissions to read files from folder “%s”"),
 					   utf8_path);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
@@ -458,6 +458,7 @@ dlg_add_folder_load_last_options (DialogData *data)
 	g_free (include_files);
 	g_free (exclude_files);
 	g_free (exclude_folders);
+	g_list_free_full (files, (GDestroyNotify) g_object_unref);
 }
 
 
