@@ -200,7 +200,9 @@ fr_command_dpkg_extract (FrCommand  *comm,
 }
 
 
-const char *dpkg_mime_type[] = { "application/x-deb", NULL };
+const char *dpkg_mime_type[] = { "application/vnd.debian.binary-package",
+				 "application/x-deb",
+				 NULL };
 
 
 static const char **
